@@ -1,4 +1,5 @@
 """Utilities for mocking ansible modules and roles."""
+
 from __future__ import annotations
 
 import contextlib
@@ -46,7 +47,7 @@ def _make_module_stub(module_name: str, options: Options) -> None:
         path.mkdir(exist_ok=True, parents=True)
         _write_module_stub(
             filename=module_file,
-            name=module_file,
+            name=module_name,
             namespace=namespace,
             collection=collection,
         )
